Chapter 4: Pixelizations
========================

In chapter 4, we use **Pixelizations** to reconstruct complex galaxies on pixelized grids.

The chapter contains the following tutorials:

`Tutorial 1: Pixelizations <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_4_pixelizations/tutorial_1_pixelizations.ipynb>`_
- Creating a pixel-grid which will reconstruct a galaxy's light.

`Tutorial 2: Mappers <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_4_pixelizations/tutorial_2_mappers.ipynb>`_
- How a pixelization maps between the data and pixelization.

`Tutorial 3: Inversions <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_4_pixelizations/tutorial_3_inversions.ipynb>`_
- Inverting the mappings to reconstruct the galaxy's light.

`Tutorial 4: Bayesian Regularization <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_4_pixelizations/tutorial_4_bayesian_regularization.ipynb>`_
- Smoothing the source within a Bayesian framework.

`Tutorial 6: Model Fit <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_4_pixelizations/tutorial_6_model_fit.ipynb>`_
- An example modeling pipeline which uses an inversion.